@@ -1,6 +1,6 @@
 use super::*;
 
-pub fn to_ident(name: &str) -> Ident {
+pub fn to_ident(name: &str) -> TokenStream {
     // keywords list based on https://doc.rust-lang.org/reference/keywords.html
     match name {
         "abstract" | "as" | "become" | "box" | "break" | "const" | "continue" | "crate" | "do"
@@ -8,13 +8,13 @@ pub fn to_ident(name: &str) -> Ident {
         | "let" | "loop" | "macro" | "match" | "mod" | "move" | "mut" | "override" | "priv"
         | "pub" | "ref" | "return" | "static" | "struct" | "super" | "trait" | "true" | "type"
         | "typeof" | "unsafe" | "unsized" | "use" | "virtual" | "where" | "while" | "yield"
-        | "try" | "async" | "await" | "dyn" => format_ident!("r#{}", name),
-        "Self" | "self" => format_ident!("{}_", name),
-        "_" => format_ident!("unused"),
-        _ => format_ident!("{}", name),
+        | "try" | "async" | "await" | "dyn" => format_token!("r#{}", name),
+        "Self" | "self" => format_token!("{}_", name),
+        "_" => "unused".into(),
+        _ => name.into(),
     }
 }
 
-pub fn to_abi_ident(name: &str) -> Ident {
-    format_ident!("{}_abi", name)
+pub fn to_abi_ident(name: &str) -> TokenStream {
+    format_token!("{}_abi", name)
 }
